@@ -16,7 +16,7 @@ from cuser.middleware import CuserMiddleware
 from tracking_fields.models import (
     TrackingEvent, CREATE, UPDATE, DELETE, ADD, REMOVE, CLEAR,
 )
-from tracking_fields.tests.models import Human, Pet, House
+from tracking_fields.tests.models import Human, Pet, House, UuidModel
 
 
 class TrackingEventTestCase(TestCase):
@@ -65,7 +65,7 @@ class TrackingEventTestCase(TestCase):
         assert human_event.action == UPDATE
         assert human_event.object == self.human
         assert human_event.object_repr == self.human_repr
-        assert human_event.user == None
+        assert human_event.user is None
         assert human_event.user_repr == 'None'
         tracking.CUSER = True
 
@@ -95,7 +95,7 @@ class TrackingEventTestCase(TestCase):
         human_event = events.last()
         assert human_event.date is not None
         assert human_event.action == DELETE
-        assert human_event.object == None  # Object is deleted
+        assert human_event.object is None  # Object is deleted
         assert human_event.object_repr == self.human_repr
         assert human_event.user == self.user
         assert human_event.user_repr == self.user_repr
@@ -483,3 +483,9 @@ class AdminModelTestCase(TestCase):
             response,
             ' class="historylink">',
         )
+
+    def test_track_uuid_model(self):
+        model = UuidModel.objects.create(value="foobar")
+        model.value = "toto"
+        model.save()
+        model.delete()
